==> auto_coder-0.1.346.tar.gz: auto_coder-0.1.346/src/autocoder/common/v2/agent/agentic_edit_tools/execute_command_tool_resolver.py <==
import subprocess
import os
from typing import Dict, Any, Optional
from autocoder.common.v2.agent.agentic_edit_tools.base_tool_resolver import BaseToolResolver
from autocoder.common.v2.agent.agentic_edit_types import ExecuteCommandTool, ToolResult # Import ToolResult from types
from autocoder.common import shells
from autocoder.common.printer import Printer
from loguru import logger
import typing   
from autocoder.common import AutoCoderArgs

if typing.TYPE_CHECKING:
    from autocoder.common.v2.agent.agentic_edit import AgenticEdit

class ExecuteCommandToolResolver(BaseToolResolver):
    def __init__(self, agent: Optional['AgenticEdit'], tool: ExecuteCommandTool, args: AutoCoderArgs):
        super().__init__(agent, tool, args)
        self.tool: ExecuteCommandTool = tool # For type hinting

    def resolve(self) -> ToolResult:
        printer = Printer()
        command = self.tool.command
        requires_approval = self.tool.requires_approval
        source_dir = self.args.source_dir or "."

        # Basic security check (can be expanded)
        if ";" in command or "&&" in command or "|" in command or "`" in command:
             # Allow && for cd chaining, but be cautious
             if not command.strip().startswith("cd ") and " && " in command:
                 pass # Allow cd chaining like 'cd subdir && command'
             else:
                return ToolResult(success=False, message=f"Command '{command}' contains potentially unsafe characters.")

        # Approval mechanism (simplified)
        if requires_approval:
             # In a real scenario, this would involve user interaction
             printer.print_str_in_terminal(f"Command requires approval: {command}")
             # For now, let's assume approval is granted in non-interactive mode or handled elsewhere
             pass

        printer.print_str_in_terminal(f"Executing command: {command} in {os.path.abspath(source_dir)}")
        try:
            # Determine shell based on OS
            shell = True
            executable = None
            if shells.is_windows():
                # Decide between cmd and powershell if needed, default is cmd
                pass # shell=True uses default shell
            else:
                # Use bash or zsh? Default is usually fine.
                pass # shell=True uses default shell

            # Execute the command
            process = subprocess.Popen(
                command,
                shell=True,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                cwd=source_dir,
                text=True,
                encoding=shells.get_terminal_encoding(),
                errors='replace' # Handle potential decoding errors
            )

            stdout, stderr = process.communicate()
            returncode = process.returncode

            logger.info(f"Command executed: {command}")
            logger.info(f"Return Code: {returncode}")
            if stdout:
                logger.info(f"stdout:\n{stdout}")
            if stderr:
                logger.info(f"stderr:\n{stderr}")


            if returncode == 0:
                return ToolResult(success=True, message="Command executed successfully.", content=stdout)
            else:
                error_message = f"Command failed with return code {returncode}.\nStderr:\n{stderr}\nStdout:\n{stdout}"
                return ToolResult(success=False, message=error_message, content={"stdout": stdout, "stderr": stderr, "returncode": returncode})

        except FileNotFoundError:
            return ToolResult(success=False, message=f"Error: The command '{command.split()[0]}' was not found. Please ensure it is installed and in the system's PATH.")
        except PermissionError:
            return ToolResult(success=False, message=f"Error: Permission denied when trying to execute '{command}'.")
        except Exception as e:
            logger.error(f"Error executing command '{command}': {str(e)}")
            return ToolResult(success=False, message=f"An unexpected error occurred while executing the command: {str(e)}")

==> auto_coder-0.1.359.tar.gz: auto_coder-0.1.359/src/autocoder/common/v2/agent/agentic_edit_tools/execute_command_tool_resolver.py <==
import subprocess
import os
from typing import Dict, Any, Optional
from autocoder.common.run_cmd import run_cmd_subprocess
from autocoder.common.v2.agent.agentic_edit_tools.base_tool_resolver import BaseToolResolver
from autocoder.common.v2.agent.agentic_edit_types import ExecuteCommandTool, ToolResult # Import ToolResult from types
from autocoder.common import shells
from autocoder.common.printer import Printer
from loguru import logger
import typing   
from autocoder.common import AutoCoderArgs
from autocoder.events.event_manager_singleton import get_event_manager
from autocoder.run_context import get_run_context
if typing.TYPE_CHECKING:
    from autocoder.common.v2.agent.agentic_edit import AgenticEdit

class ExecuteCommandToolResolver(BaseToolResolver):
    def __init__(self, agent: Optional['AgenticEdit'], tool: ExecuteCommandTool, args: AutoCoderArgs):
        super().__init__(agent, tool, args)
        self.tool: ExecuteCommandTool = tool # For type hinting

    def resolve(self) -> ToolResult:
        printer = Printer()
        command = self.tool.command
        requires_approval = self.tool.requires_approval
        source_dir = self.args.source_dir or "."

        # Basic security check (can be expanded)
        if ";" in command or "&&" in command or "|" in command or "`" in command:
             # Allow && for cd chaining, but be cautious
             if not command.strip().startswith("cd ") and " && " in command:
                 pass # Allow cd chaining like 'cd subdir && command'
             else:
                return ToolResult(success=False, message=f"Command '{command}' contains potentially unsafe characters.")

        # Approval mechanism (simplified)
        if requires_approval:
             # In a real scenario, this would involve user interaction
             printer.print_str_in_terminal(f"Command requires approval: {command}")
             # For now, let's assume approval is granted in non-interactive mode or handled elsewhere
             pass

        printer.print_str_in_terminal(f"Executing command: {command} in {os.path.abspath(source_dir)}")
        try:            
            # 使用封装的run_cmd方法执行命令
            if get_run_context().is_web():
                answer = get_event_manager(
                    self.args.event_file).ask_user(prompt=f"Allow to execute the `{command}`?",options=["yes","no"])
                if answer == "yes":
                    pass
                else:
                    return ToolResult(success=False, message=f"Command '{command}' execution denied by user.")
            
            exit_code, output = run_cmd_subprocess(command, verbose=True, cwd=source_dir)

            logger.info(f"Command executed: {command}")
            logger.info(f"Return Code: {exit_code}")
            if output:
                logger.info(f"Output:\n{output}")

            if exit_code == 0:
                return ToolResult(success=True, message="Command executed successfully.", content=output)
            else:
                error_message = f"Command failed with return code {exit_code}.\nOutput:\n{output}"
                return ToolResult(success=False, message=error_message, content={"output": output, "returncode": exit_code})

        except FileNotFoundError:
            return ToolResult(success=False, message=f"Error: The command '{command.split()[0]}' was not found. Please ensure it is installed and in the system's PATH.")
        except PermissionError:
            return ToolResult(success=False, message=f"Error: Permission denied when trying to execute '{command}'.")
        except Exception as e:
            logger.error(f"Error executing command '{command}': {str(e)}")
            return ToolResult(success=False, message=f"An unexpected error occurred while executing the command: {str(e)}")
